@@ -686,9 +686,35 @@ def date2num(date, unit, calendar):
     if unit_string.endswith(" since epoch"):
         unit_string = unit_string.replace("epoch", EPOCH)
     cdftime = netcdftime.utime(unit_string, calendar=calendar)
+    date = _discard_microsecond(date)
     return cdftime.date2num(date)
 
 
+def _discard_microsecond(date):
+    """
+    Return a date with the microsecond componenet discarded.
+
+    Works for scalars, sequences and numpy arrays. Returns a scalar
+    if input is a scalar, else returns a numpy array.
+
+    Args:
+
+    * date (datetime.datetime or netcdftime.datetime):
+        Date value/s
+
+    Returns:
+        datetime, or list of datetime object.
+
+    """
+    is_scalar = False
+    if not hasattr(date, '__iter__'):
+        date = [date]
+        is_scalar = True
+    dates = [d.__class__(d.year, d.month, d.day, d.hour, d.minute, d.second)
+             for d in date]
+    return dates[0] if is_scalar else dates
+
+
 def num2date(time_value, unit, calendar):
     """
     Return datetime encoding of numeric time value (resolution of 1 second).
@@ -714,6 +740,9 @@ def num2date(time_value, unit, calendar):
     do not contain a time-zone offset, even if the specified unit
     contains one.
 
+    Works for scalars, sequences and numpy arrays. Returns a scalar
+    if input is a scalar, else returns a numpy array.
+
     Args:
 
     * time_value (float):
@@ -753,7 +782,57 @@ def num2date(time_value, unit, calendar):
     if unit_string.endswith(" since epoch"):
         unit_string = unit_string.replace("epoch", EPOCH)
     cdftime = netcdftime.utime(unit_string, calendar=calendar)
-    return cdftime.num2date(time_value)
+    return _num2date_to_nearest_second(time_value, cdftime)
+
+
+def _num2date_to_nearest_second(time_value, utime):
+    """
+    Return datetime encoding of numeric time value with respect to the given
+    time reference units, with a resolution of 1 second.
+
+    * time_value (float):
+        Numeric time value/s.
+    * utime (netcdftime.utime):
+        netcdf.utime object with which to perform the conversion/s.
+
+    Returns:
+        datetime, or numpy.ndarray of datetime object.
+    """
+    is_scalar = False
+    if not hasattr(time_value, '__iter__'):
+        time_value = [time_value]
+        is_scalar = True
+    time_values = np.array(list(time_value))
+
+    # We account for the edge case where the time is in seconds and has a
+    # half second: utime.num2date() may produce a date that would round
+    # down.
+    #
+    # Note that this behaviour is different to the num2date function in older
+    # versions of netcdftime that didn't have microsecond precision. In those
+    # versions, a half-second value would be rounded up or down arbitrarily. It
+    # is probably not possible to replicate that behaviour with the current
+    # version (1.4.1), if one wished to do so for the sake of consistency.
+    has_half_seconds = np.logical_and(utime.units == 'seconds',
+                                      time_values % 1. == 0.5)
+    dates = utime.num2date(time_values)
+    try:
+        # We can assume all or none of the dates have a microsecond attribute
+        microseconds = np.array([d.microsecond for d in dates])
+    except AttributeError:
+        microseconds = 0
+    round_mask = np.logical_or(has_half_seconds, microseconds != 0)
+    ceil_mask = np.logical_or(has_half_seconds, microseconds >= 500000)
+    if time_values[ceil_mask].size > 0:
+        useconds = Unit('second')
+        second_frac = useconds.convert(0.75, utime.units)
+        dates[ceil_mask] = utime.num2date(time_values[ceil_mask] + second_frac)
+    # Create date objects of the same type returned by utime.num2date()
+    # (either datetime.datetime or netcdftime.datetime), discarding the
+    # microseconds
+    dates[round_mask] = _discard_microsecond(dates[round_mask])
+
+    return dates[0] if is_scalar else dates
 
 
 ########################################################################
@@ -2036,6 +2115,7 @@ class Unit(_OrderedHashable):
         """
 
         cdf_utime = self.utime()
+        date = _discard_microsecond(date)
         return cdf_utime.date2num(date)
 
     def num2date(self, time_value):
@@ -2078,4 +2158,4 @@ class Unit(_OrderedHashable):
 
         """
         cdf_utime = self.utime()
-        return cdf_utime.num2date(time_value)
+        return _num2date_to_nearest_second(time_value, cdf_utime)
